@@ -3,7 +3,7 @@ package PGP::Finger::ResultSet;
 use Moose;
 
 # ABSTRACT: object to hold and merge Result objects
-our $VERSION = '1.0'; # VERSION
+our $VERSION = '1.1'; # VERSION
 
 has 'results' => (
 	is => 'ro', isa => 'ArrayRef[PGP::Finger::Result]', lazy => 1,
@@ -42,6 +42,8 @@ sub as_string {
 	foreach my $key ( @keys ) {
 		if( $type eq 'armored' ) {
 			$result .= $key->armored;
+		} elsif ( $type eq 'binary' ){
+			$result .= $key->data;
 		} elsif ( $type eq 'generic' ){
 			$result .= $key->dns_record_generic;
 		} elsif ( $type eq 'rfc' ){
@@ -68,7 +70,7 @@ PGP::Finger::ResultSet - object to hold and merge Result objects
 
 =head1 VERSION
 
-version 1.0
+version 1.1
 
 =head1 AUTHOR
 
